##############################################################################
# 
# Zope Public License (ZPL) Version 1.0
# -------------------------------------
# 
# Copyright (c) Digital Creations.  All rights reserved.
# 
# This license has been certified as Open Source(tm).
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
# 1. Redistributions in source code must retain the above copyright
#    notice, this list of conditions, and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions, and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 
# 3. Digital Creations requests that attribution be given to Zope
#    in any manner possible. Zope includes a "Powered by Zope"
#    button that is installed by default. While it is not a license
#    violation to remove this button, it is requested that the
#    attribution remain. A significant investment has been put
#    into Zope, and this effort will continue if the Zope community
#    continues to grow. This is one way to assure that growth.
# 
# 4. All advertising materials and documentation mentioning
#    features derived from or use of this software must display
#    the following acknowledgement:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    In the event that the product being advertised includes an
#    intact Zope distribution (with copyright and license included)
#    then this clause is waived.
# 
# 5. Names associated with Zope or Digital Creations must not be used to
#    endorse or promote products derived from this software without
#    prior written permission from Digital Creations.
# 
# 6. Modified redistributions of any form whatsoever must retain
#    the following acknowledgment:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    Intact (re-)distributions of any official Zope release do not
#    require an external acknowledgement.
# 
# 7. Modifications are encouraged but must be packaged separately as
#    patches to official Zope releases.  Distributions that do not
#    clearly separate the patches from the original work must be clearly
#    labeled as unofficial distributions.  Modifications which do not
#    carry the name Zope may be packaged in any form, as long as they
#    conform to all of the clauses above.
# 
# 
# Disclaimer
# 
#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
# 
# 
# This software consists of contributions made by Digital Creations and
# many individuals on behalf of Digital Creations.  Specific
# attributions are listed in the accompanying credits file.
# 
##############################################################################
""" Patches OFS.Image so that a "Text Convert" tab is available for all File Objects. """
__version__ = '1.0'

import OFS.Image, OFS.DTMLDocument, OFS.DTMLMethod
import Globals
from Globals import HTMLFile
import whrandom
try:
    import Products.ZStyleSheet.ZStyleSheet
    useZSS = 1
except:
    useZSS = 0

def performPatch():
    """ Patch the OFS.Image.File object """

    def manage_performConvert(self, convertType=''):
        """ Attempts to perform a TextConvert operation. """
        parent = self.aq_parent
        destName = "%s" % self.id()
        while hasattr(parent, destName):
            destName = "%s_%d" % (self.id(), whrandom.uniform(1000, 10000))
        data = self.__str__()
        data = """<dtml-call "RESPONSE.setHeader('content-type', '%s')">\n\n""" % self.content_type
        result = "<h4>Converting to %s called %s</h4>\n" % (convertType, destName)
        if convertType == 'DTML Method':
            OFS.DTMLMethod.addDTMLMethod(parent, id=destName, title=self.title, file=data)
        elif convertType == 'DTML Document':
            OFS.DTMLDocument.addDTMLDocument(parent, id=destName, title=self.title, file=data)
        elif convertType == 'ZStyleSheet':
            if useZSS:
                Products.ZStyleSheet.ZStyleSheet.manage_addZStyleSheet(parent, id=destName, title=self.title, file=self.__str__())
            else:
                raise   "Conversion Error", """
Sorry, but you don't have ZStyleSheet installed.  Go to <a
href="http://www.zope.org/Members/haqa/ZStyleSheet">http://www.zope.org/Members/haqa/ZStyleSheet</a>
for the latest version.
"""
        else:
            raise "Conversion Error", "What did you want to convert TO?"
        result = result + "<h4>Done!</h4>\n";
        result = result + """<h5>Click here to <a href="%s/%s/manage_workspace">View/Edit %s</a></h5>\n""" %(parent.absolute_url(), destName, destName)
        result = result + """<h5>Click here to <a href="%s/manage_workspace">View/Edit folder containing %s and %s</a></h5>\n""" %(parent.absolute_url(), self.id(), destName)

        return result

    # Remove any existing patch (For refresh to work properly)
    product = OFS.Image.File
    if product.__dict__.has_key('manage_options'):
        newOptions = []
        for option in product.manage_options:
            if not option.has_key('label') or option['label'] != 'Text Convert':
                newOptions.append(option)
        product.manage_options = tuple(newOptions)

    convertOptions = ['DTML Document', 'DTML Method']
    if useZSS:
        convertOptions.append('ZStyleSheet')   

    # Now apply the patch
    product.manage_options = product.manage_options + (
        {'label':'Text Convert', 'action':'manage_convert'},
    )
    OFS.Image.File.manage_convert = HTMLFile('convert', globals())
    OFS.Image.File.manage_performConvert = manage_performConvert
    OFS.Image.File.convertOptions = convertOptions
    
    # Reinitialize permissions for OFS.Image.File to get access to new properties.
#    Globals.default__class_init__(App.Product.Product)

performPatch()
